=======
History
=======

0.0.1 (2024-03-26)
------------------

* First release on PyPI.

0.0.5 (2024-03-26)
------------------

* Modfying authors and readme file

0.0.7 (2024-04-18)
------------------

* Adding calculation of Domestic Hot Water - DHW NEed according to the ISO 12831-3
* Adding example of DHW calculation

2.0.0 (2025-11-19)
------------------

* Adding multizone calculation considering not - thermal adjacent zones
* Adding adiabtic wall calculation for adjacent zone having the same intended use ad the thermal zone
* Adding calculation of natural ventilation using the ISO EN 156798-7
* Adding categories profiles based on the annex of ISO EN 156798-1
* Adding calculation procedure of primary energy using the ISO EN 15316-1
* Reshape the building and havc inputs in a more user-friendly way
* Adding example of multizone calculation

2.0.1 and 2.0.2 (2025-11-24)
------------------
* Update information regarding authors, license, etc.
